# Generated by Django 4.2.23 on 2025-08-07 13:54

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('anomalytracker', '0002_default_config'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='anomalies',
            name='unique_anom_per_system',
        ),
    ]
